@@ -10,20 +10,25 @@
 #include <QString>
 #include <memory>
 
-#include "kldap_export.h"
+#include "kldap_core_export.h"
 #include "ldapserver.h"
 #include "ldapurl.h"
 
-namespace KLDAP
+namespace KLDAPCore
 {
 /**
  * @brief
  * This class represents a connection to an LDAP server.
  */
-class KLDAP_EXPORT LdapConnection
+class KLDAP_CORE_EXPORT LdapConnection
 {
 public:
-    enum SASL_Fields { SASL_Authname = 0x1, SASL_Authzid = 0x2, SASL_Realm = 0x4, SASL_Password = 0x8 };
+    enum SASL_Fields {
+        SASL_Authname = 0x1,
+        SASL_Authzid = 0x2,
+        SASL_Realm = 0x4,
+        SASL_Password = 0x8,
+    };
 
     /** Constructs an LdapConnection object */
     LdapConnection();
@@ -62,7 +67,7 @@ public:
     /**
      * Returns a translated error string if connect() failed.
      */
-    Q_REQUIRED_RESULT QString connectionError() const;
+    [[nodiscard]] QString connectionError() const;
     /**
      *  Closes the LDAP connection.
      */
@@ -71,36 +76,36 @@ public:
     /** Sets the size limit for the connection.
      *  @param sizelimit the connection size limit to set
      */
-    Q_REQUIRED_RESULT bool setSizeLimit(int sizelimit);
+    [[nodiscard]] bool setSizeLimit(int sizelimit);
     /** Returns the current size limit. */
-    Q_REQUIRED_RESULT int sizeLimit() const;
+    [[nodiscard]] int sizeLimit() const;
 
     /** Sets the time limit for the connection.
      *  @param timelimit the connection time limit to set
      */
-    Q_REQUIRED_RESULT bool setTimeLimit(int timelimit);
+    [[nodiscard]] bool setTimeLimit(int timelimit);
     /** Returns the current time limit. */
-    Q_REQUIRED_RESULT int timeLimit() const;
+    [[nodiscard]] int timeLimit() const;
 
     /** Gets an option from the connection. The option value can be client
      * library specific, so avoid this function if possible
      * @param option the connection option to return
      * @param value the value of option to get
      */
-    int getOption(int option, void *value) const;
+    [[nodiscard]] int getOption(int option, void *value) const;
     /** Sets an option in the connection. The option value can be client
      * library specific, so avoid this function if possible */
     int setOption(int option, void *value);
 
     /** Returns the LDAP error code from the last operation */
-    Q_REQUIRED_RESULT int ldapErrorCode() const;
+    [[nodiscard]] int ldapErrorCode() const;
     /** Returns the LDAP error string from the last operation */
-    Q_REQUIRED_RESULT QString ldapErrorString() const;
+    [[nodiscard]] QString ldapErrorString() const;
     /** Returns a translated error message from the specified LDAP error code */
-    Q_REQUIRED_RESULT static QString errorString(int code);
+    [[nodiscard]] static QString errorString(int code);
 
     /** Returns the SASL error string from the last SASL operation */
-    Q_REQUIRED_RESULT QString saslErrorString() const;
+    [[nodiscard]] QString saslErrorString() const;
 
     /**
      * Returns the opaqe client-library specific LDAP object.
